summaryrefslogtreecommitdiff
path: root/deploy.sh
diff options
context:
space:
mode:
Diffstat (limited to 'deploy.sh')
-rwxr-xr-xdeploy.sh4
1 files changed, 2 insertions, 2 deletions
diff --git a/deploy.sh b/deploy.sh
index ce1a7bd..576898f 100755
--- a/deploy.sh
+++ b/deploy.sh
@@ -6,7 +6,7 @@
if FORCE_BUILD=$(date +%s) cargo build --workspace --release; then
# Export
if cargo run --manifest-path crates/build_helper/Cargo.toml --bin exporter; then
- # Delete compile_info.rs after successful export
- rm -f src/data/compile_info.rs
+ # Copy compile_info.rs.template to compile_info.rs after successful export
+ cp -f src/data/compile_info.rs.template src/data/compile_info.rs
fi
fi